==> customize-easy-ui-component-4.1.7.tgz: package/esm/IconButton.js <==
import * as tslib_1 from "tslib";
/** @jsx jsx */
import { jsx } from "@emotion/core";
import * as React from "react";
import { Button, getHeight } from "./Button";
import VisuallyHidden from "@reach/visually-hidden";
import PropTypes from "prop-types";
import { IconWrapper } from "./IconWrapper";
import { IconX } from "./Icons";
import { useTheme } from "./Theme/Providers";
/**
 * A component which composes Button and Icon to provide
 * interactive icon elements.
 */
export var IconButton = React.forwardRef(function (_a, ref) {
    var _b;
    var label = _a.label, _c = _a.size, size = _c === void 0 ? "md" : _c, icon = _a.icon, onPress = _a.onPress, _d = _a.color, color = _d === void 0 ? "currentColor" : _d, other = tslib_1.__rest(_a, ["label", "size", "icon", "onPress", "color"]);
    var theme = useTheme();
    return (jsx(Button, tslib_1.__assign({ ref: ref, size: size, css: (_b = {
                padding: 0
            },
            _b[theme.mediaQueries.sm] = {
                padding: 0,
            },
            _b[theme.mediaQueries.lg] = {
                padding: 0,
            },
            _b.width = getHeight(size),
            _b), onPress: onPress }, other),
        jsx(VisuallyHidden, null, label),
        jsx(IconWrapper, { color: color, size: size }, icon)));
});
IconButton.displayName = "IconButton";
IconButton.propTypes = {
    icon: PropTypes.node.isRequired,
    color: PropTypes.string,
    label: PropTypes.string.isRequired,
    variant: PropTypes.oneOf(["outline", "default", "ghost"]),
    size: PropTypes.oneOf(["xs", "sm", "md", "lg", "xl"])
};
export var CloseButton = function (_a) {
    var _b = _a.label, label = _b === void 0 ? "Close" : _b, other = tslib_1.__rest(_a, ["label"]);
    return (jsx(IconButton, tslib_1.__assign({ variant: "ghost", label: label, icon: jsx(IconX, null) }, other)));
};
CloseButton.propTypes = {
    label: PropTypes.string,
    color: PropTypes.string,
    variant: PropTypes.oneOf(["outline", "default", "ghost"]),
    size: PropTypes.oneOf(["xs", "sm", "md", "lg", "xl"])
};

==> customize-easy-ui-component-4.2.0.tgz: package/esm/IconButton.js <==
import { __rest } from "tslib";
/** @jsx jsx */
import { jsx } from "@emotion/core";
import * as React from "react";
import { Button, getHeight } from "./Button";
import VisuallyHidden from "@reach/visually-hidden";
import PropTypes from "prop-types";
import { IconWrapper } from "./IconWrapper";
import { IconX } from "./Icons";
import { useTheme } from "./Theme/Providers";
/**
 * A component which composes Button and Icon to provide
 * interactive icon elements.
 */
export const IconButton = React.forwardRef((_a, ref) => {
    var { label, size = "md", icon, onPress, color = "currentColor" } = _a, other = __rest(_a, ["label", "size", "icon", "onPress", "color"]);
    const theme = useTheme();
    return (jsx(Button, Object.assign({ ref: ref, size: size, css: {
            padding: 0,
            [theme.mediaQueries.sm]: {
                padding: 0,
            },
            [theme.mediaQueries.lg]: {
                padding: 0,
            },
            width: getHeight(size)
        }, onPress: onPress }, other),
        jsx(VisuallyHidden, null, label),
        jsx(IconWrapper, { color: color, size: size }, icon)));
});
IconButton.displayName = "IconButton";
IconButton.propTypes = {
    icon: PropTypes.node.isRequired,
    color: PropTypes.string,
    label: PropTypes.string.isRequired,
    variant: PropTypes.oneOf(["outline", "default", "ghost"]),
    size: PropTypes.oneOf(["xs", "sm", "md", "lg", "xl"])
};
export const CloseButton = (_a) => {
    var { label = "Close" } = _a, other = __rest(_a, ["label"]);
    return (jsx(IconButton, Object.assign({ variant: "ghost", label: label, icon: jsx(IconX, null) }, other)));
};
CloseButton.propTypes = {
    label: PropTypes.string,
    color: PropTypes.string,
    variant: PropTypes.oneOf(["outline", "default", "ghost"]),
    size: PropTypes.oneOf(["xs", "sm", "md", "lg", "xl"])
};
